.. _swag:

Swag
====

Swag: T-Shirts, Stickers, and Other Merchandise
-----------------------------------------------

Currently, T-shirts are available via `Spreadshirt <http://pyladies.spreadshirt.com/>`_. Proceeds from the shop benefit the PyLadies organization and go toward things like nonprofit corporation setup, helping new chapters, servers, etc.

Sometimes we also create limited runs of T-shirts, stickers, etc. Check the blog or ask around in IRC #pyladies if you’re interested in seeing what we have.

Local chapter merchandise
-------------------------

If you’d like to create merchandise for your own chapter, you can create a shop on Spreadshirt, Zazzle, or any other print-on-demand site and have the proceeds go toward your chapter.

Or you can have a local print shop print a small run.